package ai.pai.ptp.test;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.View;
import android.widget.ImageView;
import android.widget.ListView;

import com.remoteyourcam.usb.ptp.Camera;
import com.remoteyourcam.usb.ptp.PtpConstants;
import com.remoteyourcam.usb.ptp.PtpService;
import com.remoteyourcam.usb.ptp.model.LiveViewData;
import com.remoteyourcam.usb.ptp.model.ObjectInfo;

import ai.pai.ptp.R;


public class MyTestActivity extends Activity implements Camera.CameraListener, Camera.StorageInfoListener, Camera.RetrieveImageInfoListener {

    private ImageView photoIv;
    private MyTestAdapter adapter;

    private PtpService ptp;
    private Camera camera;
    private boolean isInStart;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_my_test);

        ptp = PtpService.Singleton.getInstance(this);

        photoIv = (ImageView) findViewById(R.id.iv_latest_photo);
        ListView infoListView = (ListView) findViewById(R.id.list_info);
        adapter = new MyTestAdapter(this, infoListView);
        infoListView.setAdapter(adapter);

        findViewById(R.id.btn_get_devece_info).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (camera != null) {
                    adapter.addInfo(camera.getDeviceInfo());
                } else {
                    adapter.addInfo("未发现相机设备");
                    ptp.initialize(MyTestActivity.this, getIntent());
                }
            }
        });

        findViewById(R.id.btn_capture_photo).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (camera != null) {
                    camera.capture();
                } else {
                    ptp.initialize(MyTestActivity.this, getIntent());
                }
            }
        });

        findViewById(R.id.btn_get_photos).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (camera != null) {
                    camera.retrieveImageHandles(MyTestActivity.this, 0xFFFFFFFF, PtpConstants.ObjectFormat.EXIF_JPEG);
                } else {
                    ptp.initialize(MyTestActivity.this, getIntent());
                }
            }
        });
    }

    @Override
    protected void onStart() {
        super.onStart();
        isInStart = true;
        ptp.setCameraListener(this);
        ptp.initialize(this, getIntent());
    }

    @Override
    protected void onStop() {
        super.onStop();
        isInStart = false;
        ptp.setCameraListener(null);
        if (isFinishing()) {
            ptp.shutdown();
        }
    }

    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        this.setIntent(intent);
        if (isInStart) {
            ptp.initialize(this, intent);
        }
    }

    @Override
    public void onCameraStarted(Camera camera) {
        this.camera = camera;
        adapter.addInfo("开始会话");

    }

    @Override
    public void onCameraStopped(Camera camera) {
        this.camera = null;
        adapter.addInfo("结束会话");
    }

    @Override
    public void onNoCameraFound() {
        adapter.addInfo("没有发现相机设备");
    }

    @Override
    public void onError(String message) {
        adapter.addInfo("发生错误 " + message);
        camera = null;
    }

    @Override
    public void onPropertyChanged(int property, int value) {

    }

    @Override
    public void onPropertyStateChanged(int property, boolean enabled) {

    }

    @Override
    public void onPropertyDescChanged(int property, int[] values) {

    }

    @Override
    public void onLiveViewStarted() {

    }

    @Override
    public void onLiveViewData(LiveViewData data) {

    }

    @Override
    public void onLiveViewStopped() {

    }

    @Override
    public void onCapturedPictureReceived(int objectHandle, String filename, Bitmap thumbnail, Bitmap bitmap) {
        adapter.addInfo("收到新照片 ");
        photoIv.setImageBitmap(bitmap);
    }

    @Override
    public void onBulbStarted() {

    }

    @Override
    public void onBulbExposureTime(int seconds) {

    }

    @Override
    public void onBulbStopped() {

    }

    @Override
    public void onFocusStarted() {

    }

    @Override
    public void onFocusEnded(boolean hasFocused) {

    }

    @Override
    public void onFocusPointsChanged() {

    }

    @Override
    public void onObjectAdded(int handle, int format) {
        adapter.addInfo("相机系统发现新文件 ,文件句柄 =" + handle + " format = " + format);
        if (camera == null) {
            return;
        }
        if (format == PtpConstants.ObjectFormat.EXIF_JPEG) {
            camera.retrievePicture(handle);
        }
    }

    @Override
    public void onLogMessage(String msg) {
        adapter.addInfo(msg);
    }

    @Override
    public void onStorageFound(final int handle, String label) {
        adapter.addInfo("找到相机存储卡位置，句柄=" + handle + " label = " + label);
        photoIv.post(new Runnable() {
            @Override
            public void run() {
                camera.retrieveImageHandles(MyTestActivity.this, handle, PtpConstants.ObjectFormat.EXIF_JPEG);
            }
        });
    }

    @Override
    public void onAllStoragesFound() {
        adapter.addInfo("相机存储卡查找完成");
    }

    @Override
    public void onImageHandlesRetrieved(final int[] handles) {
        adapter.addInfo("找到相机存储图像文件，共" + handles.length + "张");
        photoIv.post(new Runnable() {
            @Override
            public void run() {
                camera.retrieveImageInfo(MyTestActivity.this, handles[0]);
            }
        });
    }

    @Override
    public void onImageInfoRetrieved(int objectHandle, ObjectInfo objectInfo, final Bitmap thumbnail) {
        adapter.addInfo("找到相机存储图像文件，句柄=" + objectHandle + " info = " + objectInfo);
        photoIv.post(new Runnable() {
            @Override
            public void run() {
                photoIv.setImageBitmap(thumbnail);
            }
        });

    }
}
